/**
 *
 */
package org.gcube.datatransfer.resolver.services;

import java.net.URI;
import java.net.URISyntaxException;

import javax.annotation.Nullable;
import javax.servlet.http.HttpServletRequest;
import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.QueryParam;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.Response.Status;

import org.gcube.datatransfer.resolver.services.exceptions.BadRequestException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


/**
 *
 * @author Francesco Mangiacrapa francesco.mangiacrapa@isti.cnr.it
 * Oct 22, 2018
 */
@Path("/")
public class SMPIDResolver {

	private static final String SMP_ID = "smp-id";

	private static Logger logger = LoggerFactory.getLogger(SMPIDResolver.class);
	/**
	 * Gets the smpid.
	 *
	 * @param smpId the smp id
	 * @param fileName the file name
	 * @param contentType the content type
	 * @param validation the validation
	 * @return the smpid
	 */
	@GET
	@Path("id")
	public Response getSMPID(@Context HttpServletRequest httpRequest, @QueryParam(SMP_ID) @Nullable String smpId, @QueryParam(ConstantsResolver.FILE_NAME) String fileName, @QueryParam(ConstantsResolver.CONTENT_TYPE) String contentType,  @QueryParam(ConstantsResolver.VALIDATION) Boolean validation){
		logger.info("resolve smp-id called");

		//Checking mandatory parameter smpId
		if(smpId==null || smpId.isEmpty()){
			logger.error(SMP_ID+" not found");
			try {
				throw new BadRequestException(httpRequest, Status.NOT_ACCEPTABLE, "Missing mandatory parameter "+SMP_ID, SMPIDResolver.class, new URI("https://wiki.gcube-system.org/gcube/URI_Resolver#SMP-ID_Resolver"));
			}
			catch (URISyntaxException e) {
				//silent
			}
		}

		return StorageIDResolver.resolveStorageId(httpRequest, smpId, fileName, contentType, validation);

	}
}
