/**
 *
 */
package org.gcube.datatransfer.resolver.services.exceptions;


import java.net.URI;

import javax.servlet.http.HttpServletRequest;
import javax.ws.rs.WebApplicationException;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.Response.Status;

import org.gcube.datatransfer.resolver.Util;
import org.gcube.datatransfer.resolver.services.error.ErrorReport;
import org.gcube.datatransfer.resolver.services.error.ExceptionReport;
;


/**
 * The Class WrongParameterException.
 *
 * @author Francesco Mangiacrapa at ISTI-CNR (francesco.mangiacrapa@isti.cnr.it)
 * Oct 22, 2018
 */
public class WrongParameterException extends WebApplicationException {

    /**
	 *
	 */
	private static final long serialVersionUID = -7600028435121268528L;


	/**
	 * Instantiates a new wrong parameter exception.
	 *
	 * @param request the request
	 * @param httpReturnStatus the http return status
	 * @param message the message
	 * @param reportedBySource the reported by source
	 */
	public WrongParameterException(HttpServletRequest request, Status httpReturnStatus, String message, Class reportedBySource, URI help) {
		super(Response.status(httpReturnStatus).entity(
			ExceptionReport.builder().
			request(Util.getFullURL(request)).
			method(request.getMethod()).
			success(false).
			help(help).
			error(
				ErrorReport.builder().
				httpErrorCode(Status.BAD_REQUEST.getStatusCode()).
				name(Status.BAD_REQUEST.name())
				.message(message).
				reportedBy(reportedBySource.getName()).build())
		    .build())
			.type(MediaType.APPLICATION_XML).build());

    }
}